## Pinhole Map

The Pinhole Map is a static calibration file that provides a list wavelength $\lambda$, order number $n$ and slit position $s$ of the arc-lines from a multi-pinhole exposure alongside a first approximation of their ($X, Y$) pixel-positions on the detector.
